@@ -205,8 +205,11 @@ static int nina__read1(struct ${FILENAME}_tag *b, nina_stream_t stream) {
 	s = b->state;  b->state = 0;
 	f = ${LEXER}__accepted(b);
 	p = buf;
-	while(o == 0 && (a = nina__read1ul(b, stream)) >= 0) {
-		if(${LEXER}__step(b, a) == 0) {
+	while(o == 0) {
+		if((a = nina__read1ul(b, stream)) < 0) {
+			o = ${LEXER}__gettoken(b, buf);
+			break;
+		} else if(${LEXER}__step(b, a) == 0) {
 			if(f) {
 				b->_unreadl = a;
 				*p = 0;  o = ${LEXER}__gettoken(b, buf);
